summaryrefslogtreecommitdiffstats
path: root/kmail/messagecomposer.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/messagecomposer.cpp')
-rw-r--r--kmail/messagecomposer.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmail/messagecomposer.cpp b/kmail/messagecomposer.cpp
index 8b3f1c5c..2ff7cd6a 100644
--- a/kmail/messagecomposer.cpp
+++ b/kmail/messagecomposer.cpp
@@ -1000,7 +1000,7 @@ void MessageComposer::composeMessage()
}
//
-// These are replacements for StructuringInfo(Wrapper):
+// These are tqreplacements for StructuringInfo(Wrapper):
//
// check whether to use multipart/{signed,encrypted}
@@ -1137,7 +1137,7 @@ static inline GpgME::Context::SignatureMode signingMode( Kleo::CryptoMessageForm
}
//
-// END replacements for StructuringInfo(Wrapper)
+// END tqreplacements for StructuringInfo(Wrapper)
//
class EncryptMessageJob : public MessageComposerJob {
@@ -1600,7 +1600,7 @@ void MessageComposer::composeMessage( KMMessage& theMessage,
}
}
// replace simple LFs by CRLFs for all MIME supporting CryptPlugs
// according to RfC 2633, 3.1.1 Canonicalization
//kdDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;
mEncodedBody = KMail::Util::lf2crlf( mEncodedBody );
@@ -1700,7 +1700,7 @@ void MessageComposer::encryptMessage( KMMessage* msg,
}
// now do the encrypting:
// replace simple LFs by CRLFs for all MIME supporting CryptPlugs
// according to RfC 2633, 3.1.1 Canonicalization
//kdDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;
innerContent = KMail::Util::lf2crlf( innerContent );
@@ -1792,7 +1792,7 @@ void MessageComposer::addBodyAndAttachments( KMMessage* msg,
delete innerDwPart;
innerDwPart = 0;
// replace simple LFs by CRLFs for all MIME supporting CryptPlugs
// according to RfC 2633, 3.1.1 Canonicalization
//kdDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;
encodedAttachment = KMail::Util::lf2crlf( encodedAttachment );
@@ -1928,7 +1928,7 @@ bool MessageComposer::processStructuringInfo( const TQString bugURL,
const TQCString boundaryCStr = KMime::multiPartBoundary();
// add "boundary" parameter
if ( makeMultiMime( format, signing ) )
- mainHeader.replace( "%boundary", boundaryCStr );
+ mainHeader.tqreplace( "%boundary", boundaryCStr );
if ( toplevelCT ) {
if ( const char * str = toplevelContentDisposition( format, signing ) ) {
@@ -2092,7 +2092,7 @@ TQByteArray MessageComposer::breakLinesAndApplyCodec()
if( mCharset == "us-ascii" ) {
cText = KMMsgBase::toUsAscii( text );
- newText = TQString::fromLatin1( cText );
+ newText = TQString::tqfromLatin1( cText );
} else if( codec == 0 ) {
kdDebug(5006) << "Something is wrong and I can not get a codec." << endl;
cText = text.local8Bit();
@@ -1600,7 +1600,7 @@ void MessageComposer::composeMessage( KMMessage& theMessage,
}
}
- // replace simple LFs by CRLFs for all MIME supporting CryptPlugs
+ // tqreplace simple LFs by CRLFs for all MIME supporting CryptPlugs
// according to RfC 2633, 3.1.1 Canonicalization
//kdDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;
@@ -1700,7 +1700,7 @@ void MessageComposer::encryptMessage( KMMessage* msg,
}
// now do the encrypting:
- // replace simple LFs by CRLFs for all MIME supporting CryptPlugs
+ // tqreplace simple LFs by CRLFs for all MIME supporting CryptPlugs
// according to RfC 2633, 3.1.1 Canonicalization
//kdDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;
@@ -1792,7 +1792,7 @@ void MessageComposer::addBodyAndAttachments( KMMessage* msg,
delete innerDwPart;
innerDwPart = 0;
- // replace simple LFs by CRLFs for all MIME supporting CryptPlugs
+ // tqreplace simple LFs by CRLFs for all MIME supporting CryptPlugs
// according to RfC 2633, 3.1.1 Canonicalization
//kdDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;